#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sourcemap
version:              0.1.6.1
visibility:           public
id:                   sourcemap-0.1.6.1-cFdzTkDbQcD0X92KG8jDH
key:                  sourcemap-0.1.6.1-cFdzTkDbQcD0X92KG8jDH
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  e070eae79f406a4995d8f7aed34d7779
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-8.10.5/site-local/sourcemap-0.1.6.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/sourcemap-0.1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/sourcemap-0.1.6.1
hs-libraries:         HSsourcemap-0.1.6.1-cFdzTkDbQcD0X92KG8jDH
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
    attoparsec-0.14.1-IwUGXYiDhQIB5nUHrI5Wg8 base-4.14.2.0
    bytestring-0.10.12.0 process-1.6.9.0 text-1.2.4.1
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

